<?php
/**
 * @package   Essentials YOOtheme Pro 1.9.2 build 0113.0249
 * @author    ZOOlanders https://www.zoolanders.com
 * @copyright Copyright (C) Joolanders, SL
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

namespace ZOOlanders\YOOessentials\Form;

use function YOOtheme\App;
use ZOOlanders\YOOessentials\Form\Http\FormSubmissionRequest;
use ZOOlanders\YOOessentials\Util\Prop;
use ZOOlanders\YOOessentials\Vendor\Respect\Validation\Rules\NullType;
use ZOOlanders\YOOessentials\Vendor\Respect\Validation\Validator;

return [

    'transforms' => [

        'render' => function (object $node, array $params) {
            /** @var FormSubmissionRequest $submission */
            $submission = app(FormSubmissionRequest::class);

            $parent = $params['parent'] ?? new \stdClass;
            $controlName = $node->controls->radio['name'];
            $controlProps = $node->controls->radio['props'];

            $id = $controlProps['id'] ?? null;
            $inheritId = $controlProps->props['id_inherit'] ?? false;

            if (($parent->type ?? '') === 'yooessentials_form_fieldset' && !$parent->props['fields_show_label']) {
                $controlProps['label'] = '';
            }

            if ($inheritId && empty($id)) {
                $id = $controlName;
            }

            $node->control = (object) [
                'id' => $id,
                'name' => $controlName,
                'errors' => $submission->validator()->errors($controlName) ?? [],
                'value' => $submission->data($controlName) ?? $controlProps['value'],
                'props' => $controlProps
            ];
        }

    ],

    'controls' => [

        'radio' => function ($node) {
            $props = Prop::filterByPrefix($node->props, 'control_');
            $name = $props['name'] ?: "radio-$node->id";
            $options = array_map(function ($child) {
                return $child->props['value'];
            }, $node->children);

            return compact('name', 'props', 'options');
        }

    ],

    'validation' => function ($control, Validator $validator, $submission) {
        if ($control['props']['required'] ?? false) {
            $validator->not(new NullType);
        }

        return $validator;
    }

];
