<?php

declare (strict_types=1);
namespace ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Credentials;

use ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Configuration;
use ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\Service\ResetInterface;
/**
 * Cache the Credential generated by the decorated CredentialProvider in memory.
 *
 * The Credential will be reused until it expires.
 *
 * @author Jérémy Derussé <jeremy@derusse.com>
 */
final class CacheProvider implements \ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Credentials\CredentialProvider, \ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\Service\ResetInterface
{
    /**
     * @var (null|Credentials)[]
     */
    private $cache = [];
    private $decorated;
    public function __construct(\ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Credentials\CredentialProvider $decorated)
    {
        $this->decorated = $decorated;
    }
    public function getCredentials(\ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Configuration $configuration) : ?\ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Credentials\Credentials
    {
        $key = \spl_object_hash($configuration);
        if (!\array_key_exists($key, $this->cache) || null !== $this->cache[$key] && $this->cache[$key]->isExpired()) {
            $this->cache[$key] = $this->decorated->getCredentials($configuration);
        }
        return $this->cache[$key];
    }
    public function reset()
    {
        $this->cache = [];
    }
}
