<?php

declare (strict_types=1);
namespace ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Credentials;

use ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Configuration;
use ZOOlanders\YOOessentials\Vendor\Psr\Cache\CacheException;
use ZOOlanders\YOOessentials\Vendor\Psr\Cache\CacheItemPoolInterface;
use ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerInterface;
/**
 * Cache the Credential generated by the decorated CredentialProvider with PSR-6.
 *
 * The Credential will be reused until it expires.
 *
 * @author Jérémy Derussé <jeremy@derusse.com>
 */
final class PsrCacheProvider implements \ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Credentials\CredentialProvider
{
    private $cache;
    private $decorated;
    private $logger;
    public function __construct(\ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Credentials\CredentialProvider $decorated, \ZOOlanders\YOOessentials\Vendor\Psr\Cache\CacheItemPoolInterface $cache, ?\ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerInterface $logger = null)
    {
        $this->decorated = $decorated;
        $this->cache = $cache;
        $this->logger = $logger;
    }
    public function getCredentials(\ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Configuration $configuration) : ?\ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Credentials\Credentials
    {
        try {
            return $this->getFromCache($configuration);
        } catch (\ZOOlanders\YOOessentials\Vendor\Psr\Cache\CacheException $e) {
            if (null !== $this->logger) {
                $this->logger->error('Failed to get AWS credentials from cache.', ['exception' => $e]);
            }
            return $this->decorated->getCredentials($configuration);
        }
    }
    /**
     * @throws CacheException
     */
    private function getFromCache(\ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Configuration $configuration) : ?\ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Credentials\Credentials
    {
        $item = $this->cache->getItem('AsyncAws.Credentials.' . \sha1(\serialize([$configuration, \get_class($this->decorated)])));
        if (!$item->isHit()) {
            $item->set($credential = $this->decorated->getCredentials($configuration));
            if (null !== $credential && null !== ($exp = $credential->getExpireDate())) {
                $item->expiresAt($exp);
                $this->cache->save($item);
            }
        }
        return $item->get();
    }
}
