<?php

/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
namespace ZOOlanders\YOOessentials\Vendor\Google\Service;

use ZOOlanders\YOOessentials\Vendor\Google\Client;
/**
 * Service definition for MyBusinessAccountManagement (v1).
 *
 * <p>
 * The My Business Account Management API provides an interface for managing
 * access to a location on Google.</p>
 *
 * <p>
 * For more information about this service, see the API
 * <a href="https://developers.google.com/my-business/" target="_blank">Documentation</a>
 * </p>
 *
 * @author Google, Inc.
 */
class MyBusinessAccountManagement extends \ZOOlanders\YOOessentials\Vendor\Google\Service
{
    public $accounts;
    public $accounts_admins;
    public $accounts_invitations;
    public $locations;
    public $locations_admins;
    /**
     * Constructs the internal representation of the MyBusinessAccountManagement
     * service.
     *
     * @param Client|array $clientOrConfig The client used to deliver requests, or a
     *                                     config array to pass to a new Client instance.
     * @param string $rootUrl The root URL used for requests to the service.
     */
    public function __construct($clientOrConfig = [], $rootUrl = null)
    {
        parent::__construct($clientOrConfig);
        $this->rootUrl = $rootUrl ?: 'https://mybusinessaccountmanagement.googleapis.com/';
        $this->servicePath = '';
        $this->batchPath = 'batch';
        $this->version = 'v1';
        $this->serviceName = 'mybusinessaccountmanagement';
        $this->accounts = new \ZOOlanders\YOOessentials\Vendor\Google\Service\MyBusinessAccountManagement\Resource\Accounts($this, $this->serviceName, 'accounts', ['methods' => ['create' => ['path' => 'v1/accounts', 'httpMethod' => 'POST', 'parameters' => []], 'get' => ['path' => 'v1/{+name}', 'httpMethod' => 'GET', 'parameters' => ['name' => ['location' => 'path', 'type' => 'string', 'required' => \true]]], 'list' => ['path' => 'v1/accounts', 'httpMethod' => 'GET', 'parameters' => ['filter' => ['location' => 'query', 'type' => 'string'], 'pageSize' => ['location' => 'query', 'type' => 'integer'], 'pageToken' => ['location' => 'query', 'type' => 'string'], 'parentAccount' => ['location' => 'query', 'type' => 'string']]], 'patch' => ['path' => 'v1/{+name}', 'httpMethod' => 'PATCH', 'parameters' => ['name' => ['location' => 'path', 'type' => 'string', 'required' => \true], 'updateMask' => ['location' => 'query', 'type' => 'string'], 'validateOnly' => ['location' => 'query', 'type' => 'boolean']]]]]);
        $this->accounts_admins = new \ZOOlanders\YOOessentials\Vendor\Google\Service\MyBusinessAccountManagement\Resource\AccountsAdmins($this, $this->serviceName, 'admins', ['methods' => ['create' => ['path' => 'v1/{+parent}/admins', 'httpMethod' => 'POST', 'parameters' => ['parent' => ['location' => 'path', 'type' => 'string', 'required' => \true]]], 'delete' => ['path' => 'v1/{+name}', 'httpMethod' => 'DELETE', 'parameters' => ['name' => ['location' => 'path', 'type' => 'string', 'required' => \true]]], 'list' => ['path' => 'v1/{+parent}/admins', 'httpMethod' => 'GET', 'parameters' => ['parent' => ['location' => 'path', 'type' => 'string', 'required' => \true]]], 'patch' => ['path' => 'v1/{+name}', 'httpMethod' => 'PATCH', 'parameters' => ['name' => ['location' => 'path', 'type' => 'string', 'required' => \true], 'updateMask' => ['location' => 'query', 'type' => 'string']]]]]);
        $this->accounts_invitations = new \ZOOlanders\YOOessentials\Vendor\Google\Service\MyBusinessAccountManagement\Resource\AccountsInvitations($this, $this->serviceName, 'invitations', ['methods' => ['accept' => ['path' => 'v1/{+name}:accept', 'httpMethod' => 'POST', 'parameters' => ['name' => ['location' => 'path', 'type' => 'string', 'required' => \true]]], 'decline' => ['path' => 'v1/{+name}:decline', 'httpMethod' => 'POST', 'parameters' => ['name' => ['location' => 'path', 'type' => 'string', 'required' => \true]]], 'list' => ['path' => 'v1/{+parent}/invitations', 'httpMethod' => 'GET', 'parameters' => ['parent' => ['location' => 'path', 'type' => 'string', 'required' => \true], 'filter' => ['location' => 'query', 'type' => 'string']]]]]);
        $this->locations = new \ZOOlanders\YOOessentials\Vendor\Google\Service\MyBusinessAccountManagement\Resource\Locations($this, $this->serviceName, 'locations', ['methods' => ['transfer' => ['path' => 'v1/{+name}:transfer', 'httpMethod' => 'POST', 'parameters' => ['name' => ['location' => 'path', 'type' => 'string', 'required' => \true]]]]]);
        $this->locations_admins = new \ZOOlanders\YOOessentials\Vendor\Google\Service\MyBusinessAccountManagement\Resource\LocationsAdmins($this, $this->serviceName, 'admins', ['methods' => ['create' => ['path' => 'v1/{+parent}/admins', 'httpMethod' => 'POST', 'parameters' => ['parent' => ['location' => 'path', 'type' => 'string', 'required' => \true]]], 'delete' => ['path' => 'v1/{+name}', 'httpMethod' => 'DELETE', 'parameters' => ['name' => ['location' => 'path', 'type' => 'string', 'required' => \true]]], 'list' => ['path' => 'v1/{+parent}/admins', 'httpMethod' => 'GET', 'parameters' => ['parent' => ['location' => 'path', 'type' => 'string', 'required' => \true]]], 'patch' => ['path' => 'v1/{+name}', 'httpMethod' => 'PATCH', 'parameters' => ['name' => ['location' => 'path', 'type' => 'string', 'required' => \true], 'updateMask' => ['location' => 'query', 'type' => 'string']]]]]);
    }
}
// Adding a class alias for backwards compatibility with the previous class name.
\class_alias(\ZOOlanders\YOOessentials\Vendor\Google\Service\MyBusinessAccountManagement::class, 'ZOOlanders\\YOOessentials\\Vendor\\Google_Service_MyBusinessAccountManagement');
