<?php

/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
namespace ZOOlanders\YOOessentials\Vendor\Google\Service\YouTube\Resource;

use ZOOlanders\YOOessentials\Vendor\Google\Service\YouTube\InvideoBranding;
/**
 * The "watermarks" collection of methods.
 * Typical usage is:
 *  <code>
 *   $youtubeService = new Google\Service\YouTube(...);
 *   $watermarks = $youtubeService->watermarks;
 *  </code>
 */
class Watermarks extends \ZOOlanders\YOOessentials\Vendor\Google\Service\Resource
{
    /**
     * Allows upload of watermark image and setting it for a channel.
     * (watermarks.set)
     *
     * @param string $channelId
     * @param InvideoBranding $postBody
     * @param array $optParams Optional parameters.
     *
     * @opt_param string onBehalfOfContentOwner *Note:* This parameter is intended
     * exclusively for YouTube content partners. The *onBehalfOfContentOwner*
     * parameter indicates that the request's authorization credentials identify a
     * YouTube CMS user who is acting on behalf of the content owner specified in
     * the parameter value. This parameter is intended for YouTube content partners
     * that own and manage many different YouTube channels. It allows content owners
     * to authenticate once and get access to all their video and channel data,
     * without having to provide authentication credentials for each individual
     * channel. The CMS account that the user authenticates with must be linked to
     * the specified YouTube content owner.
     */
    public function set($channelId, \ZOOlanders\YOOessentials\Vendor\Google\Service\YouTube\InvideoBranding $postBody, $optParams = [])
    {
        $params = ['channelId' => $channelId, 'postBody' => $postBody];
        $params = \array_merge($params, $optParams);
        return $this->call('set', [$params]);
    }
    /**
     * Allows removal of channel watermark. (watermarks.unsetWatermarks)
     *
     * @param string $channelId
     * @param array $optParams Optional parameters.
     *
     * @opt_param string onBehalfOfContentOwner *Note:* This parameter is intended
     * exclusively for YouTube content partners. The *onBehalfOfContentOwner*
     * parameter indicates that the request's authorization credentials identify a
     * YouTube CMS user who is acting on behalf of the content owner specified in
     * the parameter value. This parameter is intended for YouTube content partners
     * that own and manage many different YouTube channels. It allows content owners
     * to authenticate once and get access to all their video and channel data,
     * without having to provide authentication credentials for each individual
     * channel. The CMS account that the user authenticates with must be linked to
     * the specified YouTube content owner.
     */
    public function unsetWatermarks($channelId, $optParams = [])
    {
        $params = ['channelId' => $channelId];
        $params = \array_merge($params, $optParams);
        return $this->call('unset', [$params]);
    }
}
// Adding a class alias for backwards compatibility with the previous class name.
\class_alias(\ZOOlanders\YOOessentials\Vendor\Google\Service\YouTube\Resource\Watermarks::class, 'ZOOlanders\\YOOessentials\\Vendor\\Google_Service_YouTube_Resource_Watermarks');
