<?php

/*
 * This file is part of the Symfony package.
 *
 * (c) Fabien Potencier <fabien@symfony.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace ZOOlanders\YOOessentials\Vendor\Symfony\Component\HttpClient;

use ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerAwareInterface;
use ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerInterface;
use ZOOlanders\YOOessentials\Vendor\Symfony\Component\HttpClient\Exception\InvalidArgumentException;
use ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\HttpClientInterface;
use ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\ResponseInterface;
use ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\ResponseStreamInterface;
use ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\Service\ResetInterface;
/**
 * Auto-configure the default options based on the requested URL.
 *
 * @author Anthony Martin <anthony.martin@sensiolabs.com>
 */
class ScopingHttpClient implements \ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\HttpClientInterface, \ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\Service\ResetInterface, \ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerAwareInterface
{
    use HttpClientTrait;
    private $client;
    private $defaultOptionsByRegexp;
    private $defaultRegexp;
    public function __construct(\ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\HttpClientInterface $client, array $defaultOptionsByRegexp, string $defaultRegexp = null)
    {
        $this->client = $client;
        $this->defaultOptionsByRegexp = $defaultOptionsByRegexp;
        $this->defaultRegexp = $defaultRegexp;
        if (null !== $defaultRegexp && !isset($defaultOptionsByRegexp[$defaultRegexp])) {
            throw new \ZOOlanders\YOOessentials\Vendor\Symfony\Component\HttpClient\Exception\InvalidArgumentException(\sprintf('No options are mapped to the provided "%s" default regexp.', $defaultRegexp));
        }
    }
    public static function forBaseUri(\ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\HttpClientInterface $client, string $baseUri, array $defaultOptions = [], string $regexp = null) : self
    {
        if (null === $regexp) {
            $regexp = \preg_quote(\implode('', self::resolveUrl(self::parseUrl('.'), self::parseUrl($baseUri))));
        }
        $defaultOptions['base_uri'] = $baseUri;
        return new self($client, [$regexp => $defaultOptions], $regexp);
    }
    /**
     * {@inheritdoc}
     */
    public function request(string $method, string $url, array $options = []) : \ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\ResponseInterface
    {
        $e = null;
        $url = self::parseUrl($url, $options['query'] ?? []);
        if (\is_string($options['base_uri'] ?? null)) {
            $options['base_uri'] = self::parseUrl($options['base_uri']);
        }
        try {
            $url = \implode('', self::resolveUrl($url, $options['base_uri'] ?? null));
        } catch (\ZOOlanders\YOOessentials\Vendor\Symfony\Component\HttpClient\Exception\InvalidArgumentException $e) {
            if (null === $this->defaultRegexp) {
                throw $e;
            }
            $defaultOptions = $this->defaultOptionsByRegexp[$this->defaultRegexp];
            $options = self::mergeDefaultOptions($options, $defaultOptions, \true);
            if (\is_string($options['base_uri'] ?? null)) {
                $options['base_uri'] = self::parseUrl($options['base_uri']);
            }
            $url = \implode('', self::resolveUrl($url, $options['base_uri'] ?? null, $defaultOptions['query'] ?? []));
        }
        foreach ($this->defaultOptionsByRegexp as $regexp => $defaultOptions) {
            if (\preg_match("{{$regexp}}A", $url)) {
                if (null === $e || $regexp !== $this->defaultRegexp) {
                    $options = self::mergeDefaultOptions($options, $defaultOptions, \true);
                }
                break;
            }
        }
        return $this->client->request($method, $url, $options);
    }
    /**
     * {@inheritdoc}
     */
    public function stream($responses, float $timeout = null) : \ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\ResponseStreamInterface
    {
        return $this->client->stream($responses, $timeout);
    }
    public function reset()
    {
        if ($this->client instanceof \ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\Service\ResetInterface) {
            $this->client->reset();
        }
    }
    /**
     * {@inheritdoc}
     */
    public function setLogger(\ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerInterface $logger) : void
    {
        if ($this->client instanceof \ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerAwareInterface) {
            $this->client->setLogger($logger);
        }
    }
    /**
     * {@inheritdoc}
     */
    public function withOptions(array $options) : self
    {
        $clone = clone $this;
        $clone->client = $this->client->withOptions($options);
        return $clone;
    }
}
