<?php

/*
 * This file is part of the Symfony package.
 *
 * (c) Fabien Potencier <fabien@symfony.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace ZOOlanders\YOOessentials\Vendor\Symfony\Component\HttpClient;

use ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerAwareInterface;
use ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerInterface;
use ZOOlanders\YOOessentials\Vendor\Symfony\Component\HttpClient\Response\ResponseStream;
use ZOOlanders\YOOessentials\Vendor\Symfony\Component\HttpClient\Response\TraceableResponse;
use ZOOlanders\YOOessentials\Vendor\Symfony\Component\Stopwatch\Stopwatch;
use ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\HttpClientInterface;
use ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\ResponseInterface;
use ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\ResponseStreamInterface;
use ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\Service\ResetInterface;
/**
 * @author Jérémy Romey <jeremy@free-agent.fr>
 */
final class TraceableHttpClient implements \ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\HttpClientInterface, \ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\Service\ResetInterface, \ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerAwareInterface
{
    private $client;
    private $stopwatch;
    private $tracedRequests;
    public function __construct(\ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\HttpClientInterface $client, \ZOOlanders\YOOessentials\Vendor\Symfony\Component\Stopwatch\Stopwatch $stopwatch = null)
    {
        $this->client = $client;
        $this->stopwatch = $stopwatch;
        $this->tracedRequests = new \ArrayObject();
    }
    /**
     * {@inheritdoc}
     */
    public function request(string $method, string $url, array $options = []) : \ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\ResponseInterface
    {
        $content = null;
        $traceInfo = [];
        $this->tracedRequests[] = ['method' => $method, 'url' => $url, 'options' => $options, 'info' => &$traceInfo, 'content' => &$content];
        $onProgress = $options['on_progress'] ?? null;
        if (\false === ($options['extra']['trace_content'] ?? \true)) {
            unset($content);
            $content = \false;
        }
        $options['on_progress'] = function (int $dlNow, int $dlSize, array $info) use(&$traceInfo, $onProgress) {
            $traceInfo = $info;
            if (null !== $onProgress) {
                $onProgress($dlNow, $dlSize, $info);
            }
        };
        return new \ZOOlanders\YOOessentials\Vendor\Symfony\Component\HttpClient\Response\TraceableResponse($this->client, $this->client->request($method, $url, $options), $content, null === $this->stopwatch ? null : $this->stopwatch->start("{$method} {$url}", 'http_client'));
    }
    /**
     * {@inheritdoc}
     */
    public function stream($responses, float $timeout = null) : \ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\HttpClient\ResponseStreamInterface
    {
        if ($responses instanceof \ZOOlanders\YOOessentials\Vendor\Symfony\Component\HttpClient\Response\TraceableResponse) {
            $responses = [$responses];
        } elseif (!\is_iterable($responses)) {
            throw new \TypeError(\sprintf('"%s()" expects parameter 1 to be an iterable of TraceableResponse objects, "%s" given.', __METHOD__, \get_debug_type($responses)));
        }
        return new \ZOOlanders\YOOessentials\Vendor\Symfony\Component\HttpClient\Response\ResponseStream(\ZOOlanders\YOOessentials\Vendor\Symfony\Component\HttpClient\Response\TraceableResponse::stream($this->client, $responses, $timeout));
    }
    public function getTracedRequests() : array
    {
        return $this->tracedRequests->getArrayCopy();
    }
    public function reset()
    {
        if ($this->client instanceof \ZOOlanders\YOOessentials\Vendor\Symfony\Contracts\Service\ResetInterface) {
            $this->client->reset();
        }
        $this->tracedRequests->exchangeArray([]);
    }
    /**
     * {@inheritdoc}
     */
    public function setLogger(\ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerInterface $logger) : void
    {
        if ($this->client instanceof \ZOOlanders\YOOessentials\Vendor\Psr\Log\LoggerAwareInterface) {
            $this->client->setLogger($logger);
        }
    }
    /**
     * {@inheritdoc}
     */
    public function withOptions(array $options) : self
    {
        $clone = clone $this;
        $clone->client = $this->client->withOptions($options);
        return $clone;
    }
}
